# Overview

**nxt** (**/ɛn·ɛks·ti/**) is a general purpose code compositor designed for rigging, scene assembly, and automation. (node execution tree)

| Release | Dev |
| :---: | :---: |
| [![Build Status](https://travis-ci.com/nxt-dev/nxt.svg?token=rBRbAJTv2rq1c8WVEwGs&branch=release)](https://travis-ci.com/nxt-dev/nxt) | [![Build Status](https://travis-ci.com/nxt-dev/nxt.svg?token=rBRbAJTv2rq1c8WVEwGs&branch=dev)](https://travis-ci.com/nxt-dev/nxt) |

---

# Links

- [Installation](#installation)
- [Updating](#updating)
- [User Docs](https://sunriseproductions.github.io/nxt/)
- [Contributing](CONTRIBUTING.md)
- [Licensing](LICENSE)



# Installation

### Requirements
- Python >= [2.7.*](https://www.python.org/download/releases/2.7) <= [3.7.*](https://www.python.org/download/releases/3.7)

### PIP package
- From [PyPi](https://pypi.org/project/nxt-core/):
    - `pip install nxt-core`
    
- From GitHub:
    1. Download the pip source distribution(`nxt-#.#.#.tar.gz`) from the [latest release](https://github.com/nxt-dev/nxt/releases/latest)

    2. `pip install path/to/nxt-#.#.#.tar.gz`

### Maya plugin:
Distributed on the [nxt editor](https://github.com/nxt-dev/nxt_editor/) repo.

1. Download the maya module(`nxt_maya.zip`) from the [latest release](https://github.com/nxt-dev/nxt_editor/releases/latest)

2. Follow the [nxt_maya](https://github.com/nxt-dev/nxt_editor/blob/release/integration/maya/README.md) instructions (also included in the download)

# Updating

### PIP package

- From [PyPi](https://pypi.org/project/nxt-core/) (easiest):
    - `pip install -U nxt-core`

- From GitHub:
    1. Download the pip source distribution(`nxt-#.#.#.tar.gz`) from the [latest release](https://github.com/SunriseProductions/nxt/releases/latest)

    2. `pip install --upgrade path/to/nxt-#.#.#.tar.gz`

### Maya plugin:
Distributed on the [nxt editor](https://github.com/nxt-dev/nxt_editor/) repo.

1. Download the `nxt_maya` zip from the [latest release](https://github.com/SunriseProductions/nxt_editor/releases/latest)

2. Extract the zip and replace the existing nxt_maya files with the newly extracted files.

3. Re-launch Maya


## Acknowledgements

[Sunrise Productions](https://sunriseproductions.tv/) | [School of Visual Art and Design](https://www.southern.edu/visualartanddesign/)
